@@ -35,7 +35,9 @@ def _read_version_from_file():
 def _read_version_from_git():
     try:
         return (
-            subprocess.run(["git", "describe", "--always"], stdout=subprocess.PIPE)
+            subprocess.run(
+                ["git", "describe", "--always", "--tags"], stdout=subprocess.PIPE
+            )
             .stdout.decode("utf-8")
             .rstrip()
         )
